@@ -2,12 +2,11 @@
 
 """Command line interface
 
-Author: G.J.J. van den Burg
 License: See LICENSE file.
-Copyright: 2020, G.J.J. van den Burg
 """
 
 import sys
+import logging
 
 
 def main():
@@ -17,4 +16,5 @@ def main():
 
 
 if __name__ == "__main__":
+    logging.basicConfig(level=logging.INFO)
     main()
